@@ -8,11 +8,12 @@
 use std::fmt::{Display, Formatter};
 use std::io::Write;
 use std::process::{Command, Stdio};
+use std::str::FromStr;
 
 use serde::{Deserialize, Serialize};
 use thiserror::Error;
 
-use crate::architectures::Architecture;
+use crate::architectures::{Architecture, ParseError};
 use crate::archive::{Suite, SuiteOrCodename};
 use crate::version::PackageVersion;
 
@@ -88,14 +89,14 @@ impl Display for WBArchitecture {
         match self {
             WBArchitecture::Any => write!(f, "ANY"),
             WBArchitecture::All => write!(f, "ALL"),
-            WBArchitecture::Architecture(arch) => write!(f, "{}", arch),
-            WBArchitecture::ExcludeArchitecture(arch) => write!(f, "-{}", arch),
+            WBArchitecture::Architecture(arch) => write!(f, "{arch}"),
+            WBArchitecture::ExcludeArchitecture(arch) => write!(f, "-{arch}"),
         }
     }
 }
 
 impl TryFrom<&str> for WBArchitecture {
-    type Error = crate::architectures::ParseError;
+    type Error = ParseError;
 
     fn try_from(value: &str) -> Result<Self, Self::Error> {
         match value {
@@ -112,6 +113,14 @@ impl TryFrom<&str> for WBArchitecture {
     }
 }
 
+impl FromStr for WBArchitecture {
+    type Err = ParseError;
+
+    fn from_str(s: &str) -> Result<Self, Self::Err> {
+        Self::try_from(s)
+    }
+}
+
 /// Specifier for a source with version, architecture and suite
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct SourceSpecifier<'a> {
@@ -166,14 +175,14 @@ impl<'a> Display for SourceSpecifier<'a> {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         write!(f, "{}", self.source)?;
         if let Some(version) = self.version {
-            write!(f, "_{}", version)?;
+            write!(f, "_{version}")?;
         }
         write!(f, " . ")?;
         if self.architectures.is_empty() {
             write!(f, "{} ", WBArchitecture::Any)?;
         } else {
             for arch in &self.architectures {
-                write!(f, "{} ", arch)?;
+                write!(f, "{arch} ")?;
             }
         }
         write!(f, ". {}", self.suite.unwrap_or(Suite::Unstable.into()))
@@ -197,10 +206,8 @@ impl<'a> BinNMU<'a> {
         for arch in &source.architectures {
             match arch {
                 // unable to nmu with source, -source, ALL, all
-                WBArchitecture::Architecture(Architecture::Source)
-                | WBArchitecture::ExcludeArchitecture(Architecture::Source)
-                | WBArchitecture::Architecture(Architecture::All)
-                | WBArchitecture::ExcludeArchitecture(Architecture::All)
+                WBArchitecture::Architecture(Architecture::Source | Architecture::All)
+                | WBArchitecture::ExcludeArchitecture(Architecture::Source | Architecture::All)
                 | WBArchitecture::All => {
                     return Err(Error::InvalidArchitecture(*arch, "nmu"));
                 }
@@ -250,11 +257,11 @@ impl<'a> Display for BinNMU<'a> {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         write!(f, "nmu ")?;
         if let Some(nmu_version) = self.nmu_version {
-            write!(f, "{} ", nmu_version)?;
+            write!(f, "{nmu_version} ")?;
         }
         write!(f, "{} . -m \"{}\"", self.source, self.message)?;
         if let Some(extra_depends) = self.extra_depends {
-            write!(f, " --extra-depends \"{}\"", extra_depends)?;
+            write!(f, " --extra-depends \"{extra_depends}\"")?;
         }
         if let Some(dep_wait) = self.dep_wait {
             write!(
